@@ -1,18 +1,18 @@
 from . activation import USE_MISH_AS_RELU
-from . mixed_precision import USE_MIXED_PRECISION
+from . mixed_precision import ENABLE_MIXED_PRECISION
 from . mixed_precision import IS_MIXED_PRECISION
-from . resume import ENABLE_SUSPEND_RESUME_TRAIN
-from . resume import IS_SUSPEND_RESUME_TRAIN
+from . resume import ENABLE_SUSPEND_RESUME_TRAINING
+from . resume import IS_SUSPEND_RESUME_TRAINING
 from . resume import ResumeExecutor
 from . context import Context
 from . colab import Colaboratory, IS_ON_COLABOLATORY_WITH_GOOGLE_DRIVE
 
 __all__ = [
-    'USE_MIXED_PRECISION', 
+    'ENABLE_MIXED_PRECISION', 
     'IS_MIXED_PRECISION',
     'USE_MISH_AS_RELU',
-    'ENABLE_SUSPEND_RESUME_TRAIN',
-    'IS_SUSPEND_RESUME_TRAIN',
+    'ENABLE_SUSPEND_RESUME_TRAINING',
+    'IS_SUSPEND_RESUME_TRAINING',
     'ResumeExecutor',
     'Context'
 ]
\ No newline at end of file
