@@ -12,18 +12,21 @@ from . efficientnet import KerasEfficientNetB5
 from . efficientnet import KerasEfficientNetB6
 from . efficientnet import KerasEfficientNetB7
 from . efficientnet import EfficientNetB0
+from . classification import SimpleClassificationModel
 
 # from . efficientnet import KerasEfficientNetB1
 # from . efficientnet import KerasEfficientNetB2
 
-# from . small_resnet_keras_contrib import ResNet18
-# from . small_resnet_keras_contrib import ResNet34
-from . resnet import ResNet18
-from . resnet import ResNet34
-from . resnet import ResNet50
+from . small_resnet_keras_contrib import KerasResNet18
+from . small_resnet_keras_contrib import KerasResNet34
+# from . resnet import ResNet18
+# from . resnet import ResNet34
+# from . resnet import ResNet50
 
 __all__ = [
     'AbstractClassificationModel'
+    'KerasResNet18',
+    'KerasResNet34',
     'KerasResNet50',
     'KerasResNet50V2',
     'KerasMobileNetV2',
@@ -35,10 +38,8 @@ __all__ = [
     'KerasEfficientNetB5',
     'KerasEfficientNetB6',
     'KerasEfficientNetB7',
-    'ResNet18',
-    'ResNet34',
-    'ResNet50',
-    'EfficientNetB0'
+    'EfficientNetB0',
+    'SimpleClassificationModel'
 ]
 
 """
